function [sk,sesk,sx,sesx,V]=skew(x,thet,l,ip)
%
%This routine computes the skewness (sk) and standard deviation (sx)
%for a single time series, x, which is assumed to have sample mean
%equal to zero.  It also returns an estimate of the standard error
%of sk (sesk) and of sx (sesx).  The variance-covariance matrix
%of n^(1/2)*[sk,sx] is given by V*n, where n is the number of
%observations in x.  V is computed using Lars Hansen's GMM formulas,
%and thet, l are parameters which have to be set to do this.
%Set thet = 1 and l = 1,2 or 3.  For more on these, see the writeup
%to MATLAB routine CORR.M.
%  The routine assumes that the mean of x is a known number.  This
%is important.  For example, when the data are iid and normal,
%then sesx = sqrt(6/n) when the sample mean is assumed to be
%estimated, while sesx = sqrt(15/n) when the sample mean is
%assumed to be known.
%  If ip = 1, the computations are done assuming the true value
%             of sk is zero.
%  If ip = 2, the computations are done assuming the true value
%             of sk is nonzero, and equal to its estimated value.
%
n=length(x);
mx=sum(x)/n;
if abs(mx) > .000001
  disp('fatal (skew) mean of data series non-negative')
  mx
  break
end
sx=sqrt(sum(x.^2)/n);
xx=sum(x.^3)/n;
sk=xx/(sx^3);
X=zeros(n,2);
if ip == 1
  D=[-2*sx   0
     0     sx^3];
  for i=1:n
  X(i,:)=[x(i)^2-sx^2,-(x(i))^3];
  end
end
if ip == 2
  D=[-2*sx        0
     (sx^2)*sk    sx^3];
  for i=1:n
  X(i,:)=[x(i)^2-sx^2,(x(i)^2)*sk*sx-(x(i))^3];
  end
end
[V,S]=se(X,D,thet,l);
V=V/n;
sesk=sqrt(V(2,2));
sesx=sqrt(V(1,1));
