function grdd = hessian_2s(fcn,x0,grdh,varargin)
% Computing numerical hessian using a central difference with
%  function grdd = hesscd(fcn,x0,grdh,Passed variables1)
%
%   fcn: a string naming the objective function.
%   x0: a column vector n*1, at which point the hessian is evaluated.
%   grdh: step size.
%   grdd: hessian matrix (second derivative), n*n.

stps = eps^(1/3);
% eps: floating point relative accuracy or machine precision: 2.22e-16
% stps: step size recommended by Dennis and Schnabel: 6.006e-6

f0 = feval(fcn,x0,varargin{:});

%initializations
k = length(x0);
grdd = zeros(k);

%Computation of stepsize (dh)
if isempty(grdh)==0
    dh = grdh;
else
    ax0 = abs(x0);
    if all(x0)
        dax0 = x0 ./ ax0;
    else
        dax0 = 1;
    end
    dh = stps * (max([ax0 (1e-2)*ones(k,1)]'))' .* dax0;
end

xdh = x0 + dh;
dh = xdh - x0;    % This increases precision slightly
dhm = dh(:,ones(k,1));
ee = eye(k) .* dhm;

i = 1;
while i <= k
    j = i;
    while j <= k
    
		  fune1 = feval(fcn,(x0 + ee(:,i) + ee(:,j)),varargin{:});
		  fune2 = feval(fcn,(x0 - ee(:,i) + ee(:,j)),varargin{:});
		  fune3 = feval(fcn,(x0 + ee(:,i) - ee(:,j)),varargin{:});
		  fune4 = feval(fcn,(x0 - ee(:,i) - ee(:,j)),varargin{:});
        grdd(i,j) = (fune1 - fune2 - fune3 + fune4)  / (4 * dh(i) * dh(j));

        if i ~= j
            grdd(j,i) = grdd(i,j);
        end

    j = j+1;
    end
    i = i+1;
end

