function logf = logbetapdf(x,a,b);

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % PURPOSE:     Computing the log of the Beta(a,b) density
 %
 % INPUT:       x          (scalar)        Point where the density is evaluated  
 %              a          (scalar)        First parameter
 %              b          (scalar)        Second parameter
 %      
 % OUTPUT:      logf       (scalar)        Log height of the Beta(a,b) distribution
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if a <= 0 | b <= 0
    error('fatal(logbetapdf): hyperparameters a | b <0') 
end

 if x>=0.0000001 & x<=0.9999
     logf = (a - 1).*log(x) + (b - 1).*log(1 - x) - betaln(a,b);
 else
     logf = -6e10;
 end