function  micro(sigma_SS,omegabar,lev_SS,mu,sp1)

ick=0;%controls whether it is sigma (ick=0) or sp1 (ick=1) that is perturbed
indif=1;%if unity, then compute indifference curves (always do this)
om=1;% if indif = 1, om=1 means do the indifference curve in (omega,leverage), om=0 means do it in (Pe,leverage) space
   %warning, om = 0 is very time-intensive!
idx=0;%if zero, drop some graphs that were not used
   
sig=sigma_SS;
Pe_SS=sp1*omegabar*lev_SS/(lev_SS-1);

%take sp1 and sig as given and find Pe and lev that solve the CSV
%contracting problem

%step 1: find omega that solves the first order condition
[ff,G,F,Gamma,Gam_muG,Fprime]=findomeg(omegabar,sig,mu,sp1);
if abs(ff) > .1e-10
    error('fatal(micro) omegabar not a steady state')
end
%step 2: leverage and spread
lev=1/(1-Gam_muG*sp1);
Pe=sp1*omegabar*lev/(lev-1);
%the level of utility at the steady state equilibrium
Ubar=(1-Gamma)*sp1*lev;

if abs(lev - lev_SS) > .1e-10 | abs(Pe-Pe_SS) > .1e-10 
    error('fatal (micro) not a steady state')
end

%&&&&&&& for my handout &&&&&&&&&&&&
% handout graph of utility as a function of leverage for fixed spread
lever=[];
util=[];
utilp=[];
Pe_pert=1.05;
lever=1.001:.01:15;
for ii = 1:length(lever)
    leve=lever(ii);
    [ff,omega,z,G,F,Gamma,er] = leverage(Pe,leve,sp1,sig,Ubar);
    util(ii)=(1-Gamma)*sp1*leve;
    [ff,omega,z,G,F,Gamma,er] = leverage(Pe_pert,leve,sp1,sig,Ubar);
    utill(ii)=(1-Gamma)*sp1*leve;
    [ff,omega,z,G,F,Gamma,er] = leverage(Pe,leve,sp1,sig*1.02,Ubar);
    utilp(ii)=(1-Gamma)*sp1*leve;
end
plot(lever,util,lever,utill,'x-',lev_SS,Ubar,'*',lever,ones(1,length(lever)))
ss=['Z/(1+R) = ',num2str(Pe),', Annual Percentage Poins = ',num2str(400*(Pe-1))];
ss1=['Z/(1+R) = ',num2str(Pe_pert),', Annual Percentage Poins = ',num2str(400*(Pe_pert-1))];
legend(ss,ss1)
%ylabel('Ratio, expected return to opportunity cost','fontsize',32)
xlabel('leverage','fontsize',32)
title('Expected entrepreneurial return, over opportunity cost, N(1+R)','fontsize',32)
axis tight


%&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&
% graph the objective of the entrepreneur as a function of omegabar

[ff,G,F,Gamma,Gam_muG,Fprime]=findomeg(omegabar,sig,mu,sp1);
lef=(1-F)/(1-Gamma);
righ=sp1*(1-F-mu*omegabar*Fprime)/(1-sp1*Gam_muG);
ff1=lef-righ;

if abs(ff) > .1e-10 || abs(ff1) > .1e-10
    error('fatal (micro) omegabar is not solution')
end

Util=[];
left=[];
right=[];

oomega=.001:.001:1.13;
for ii=1:length(oomega)
    [ff,G,F,Gamma,Gam_muG,Fprime]=findomeg(oomega(ii),sig,mu,sp1);
    lev=1/(1-(Gam_muG)*sp1);
    left(ii)=(1-F)/(1-Gamma);
    right(ii)=sp1*(1-F-mu*oomega(ii)*Fprime)/(1-sp1*Gam_muG);
    Util(ii)=(1-Gamma)*sp1*lev;
end

[Y,I]=min(abs(oomega-omegabar));
[Y,i1]=min(abs(oomega-.25));
[Y,i2]=min(abs(oomega-.65));
tt=i1:i2;

figure('Name','entrepreneurial objective function')
subplot(221)
plot(oomega(tt),Util(tt),omegabar,Ubar,'*')
ylabel('entrepreneurial utility')
xlabel('\omega bar')
title('entrepreneurial objective as a function of \omega bar')
axis tight

subplot(222)
plot(oomega,Util,omegabar,Ubar,'*')
ylabel('entrepreneurial utility')
xlabel('\omega bar')
title('entrepreneurial objective as a function of \omega bar')
axis tight

subplot(224)
plot(oomega,-left+right)
xlabel('\omega bar')
title('derivative of log entrepreneurial objective')
axis tight

subplot(223)
plot(oomega(tt),-left(tt)+right(tt),oomega(I),-left(I)+right(I),'*-',oomega(tt),zeros(length(tt),1))
xlabel('\omega bar')
title('derivative of log entrepreneurial objective')
axis tight


%now, go for the indifference curve...
Pe_SS=sp1*omegabar*lev_SS/(lev_SS-1);

llev=1.001:.01:lev_SS*1.05;
PPe=1.001:.001:Pe_SS*(1+.2);
UU=Ubar;
if indif == 1;
    UU=Ubar*[.8:.2:9];llev=1.001:.01:4;PPe=1.001:.001:1.05;
    UU=sort([UU 1]);
    [Y,Ia]=min(abs(UU-1));
    [Y,Ib]=min(abs(UU-Ubar));
end

%easy indifference curve, the one in the (omega, leverage) space:
if indif == 1 & om == 1
    
    ttt=[];
    oomega=[];
    figure('Name','indifference curve, U(omega,lev)')
    
    oomega=.001:.001:.75;
    for ii=1:length(oomega)
        [G,F,Gamma] = valuation(oomega(ii),sig);
        ttt(ii)=(1-Gamma);
    end

    [Y,I]=min(abs(UU-Ubar));
    [Y1,I1]=min(abs(oomega-omegabar));
    
%    subplot(211)

    for jj = 1:length(UU)
        Ljj=UU(jj)./(ttt*sp1);
        %only interested in positive borrowing case, i.e., leverage>=1
        JJ=find(Ljj>=1);
        JJ1=find(Ljj<15);
        JJ2=[JJ(1):JJ1(end)];
        if jj ~= Ia && jj ~= Ib
        plot(Ljj(JJ2),oomega(JJ2))
        elseif jj == Ia
            plot(Ljj(JJ2),oomega(JJ2),'*-')            
        end
        if jj == Ib            
            ll=Ljj(JJ2);
            oo=oomega(JJ2);
        end
        
        hold on

        plot(lev_SS,omegabar,'*')

    end
    
    ylabel('\omega - bar','fontsize',24)
    xlabel('leverage','fontsize',24)
    title('Indifference curve, (leverage, \omega - bar) space','fontsize',24)
    axis tight
    
    tt2=[];
    dd=[];
    oomega=.001:.01:15;
    
    for ii=1:length(oomega)
        [G,F,Gamma] = valuation(oomega(ii),sig);
        tt2(ii)=1-(Gamma-mu*G)*sp1;
        dd(ii)=(1-F)*oomega(ii);
    end
    
    if idx == 1
        figure('Name','equilibrium')
        %   subplot(212)
        hor=1./tt2;
        plot(hor,oomega,lev_SS,omegabar,'*',ll,oo)
        ylabel('\omega - bar','fontsize',36)
        xlabel('leverage','fontsize',36)
        title('Bank zero profit condition, in (leverage, \omega - bar) space','fontsize',46)
        axis([2.015 2.016 .5005 .5015])
    end
    
    figure('Name','bank zero profit condition')
 %   subplot(212)
    hor=1./tt2;
    plot(hor,oomega,lev_SS,omegabar,'*')
    ylabel('\omega - bar','fontsize',36)
    xlabel('leverage','fontsize',36)
    title('Bank zero profit condition, in (leverage, \omega - bar) space','fontsize',46)
    axis tight
    axis([min(hor) max(hor) 0 2])

end
iip=1;
if indif == 1 & om ~= 1 & iip~=0
    %now go for the indifference curves in the (leverage, Pe) space
    %careful...this graph takes a long time to compute!
    figure('Name','Indifference curve, (Pe,leverage) space')
    Iind=[];
    llev=[];
    PPe=[];
    UU=[];
    UU=Ubar*[.8:.0025:1.1];llev=1.001:.01:4;PPe=1.001:.001:1.05;
    UU=sort([UU 1]);
    [Y,I]=min(abs(UU-1));
    [Y,I1]=min(abs(UU-Ubar));
    for ii = 1:length(UU)
        U=UU(ii);
        [indPe] = indifference(llev,PPe,sp1,sig,U);Iind=find(indPe>.0001);
        if length(UU) > 1
            if ii ~= I1 && ii ~= I
                plot(llev(Iind),indPe(Iind))
            elseif ii == I
                plot(llev(Iind),indPe(Iind),'*-')
            elseif ii == I1
                plot(llev(Iind),indPe(Iind),'o-')
            end
            hold on
        end        
    end
    plot(lev_SS,Pe_SS,'*')
    ylabel('Z/(1+R), risk spread')
    xlabel('leverage, Assets/Net Worth')
    title('Entrepreneurial indifference curves')
    axis tight
end

%now go for the comparative static exercise....in the (Pe,leverage) space
%first, get the zero profit function and indifference curves at the steady
%state equilibrium
llev=1.001:.01:lev*1.05;
PPe=1.001:.001:Pe*(1+.2);
[indPe] = indifference(llev,PPe,sp1,sig,Ubar);
[profPe] = zprofits(llev,PPe,sp1,sig,mu);
Iind=find(indPe>.0001);
Iprof=find(profPe>.0001);


%now go for the pertubed equilibrium

if ick==0 
    llevt=llev;
    ip=1.05;
    ss=['Figure  : Impact on standard debt contract of a ',num2str(100*(ip-1)),'% jump in \sigma'];
    [omega,G,F,Gamma,Gam_muG,Fprime,er] = ffindomeg(sig*ip,mu,sp1);
end
if ick==1;
    llevt=1.17:.01:1.25;
    ip=1.02;
    ss=['Figure  : Impact on standard debt contract of a ',num2str(100*(ip-1)),'% jump in R^k/R'];
    sp1=sp1*ip;
    ip=1;
    [omega,G,F,Gamma,Gam_muG,Fprime,er] = ffindomeg(sig,mu,sp1);
end

if er == 1
    error('fatal (micro) failed to find omega')
end
[ff,G,F,Gamma,Gam_muG,Fprime]=findomeg(omega,sig*ip,mu,sp1);
if abs(ff) > .1e-10
    error('fatal (micro) mistake')
end
lev=1/(1-Gam_muG*sp1);
Pe=sp1*omega*lev/(lev-1);
Ubart=(1-Gamma)*sp1*lev;

[indPet] = indifference(llevt,PPe,sp1,sig*ip,Ubart);
[profPet] = zprofits(llevt,PPe,sp1,sig*ip,mu);
Iindt=find(indPet>.0001);
Iproft=find(profPet>.0001);

figure('name','comparative static exercise')
plot(llev(Iind),400*(indPe(Iind)-1),llev(Iprof),400*(profPe(Iprof)-1),llevt(Iindt),400*(indPet(Iindt)-1),llevt(Iproft),400*(profPet(Iproft)-1),lev_SS,400*(Pe_SS-1),'*',lev,400*(Pe-1),'*')
legend('preferences','profits','preferences','profits')
xlabel('leverage, L = (B+N)/N','fontsize',28)
ylabel('risk spread, 400(Z/R-1)','fontsize',28)
title(ss,'fontsize',30)
axis([1.9 2.05 .4 1])
%axis tight

if idx==1
    figure('Name','static equilibrium (lev,omega) space')
    tt2=[];
    ttt=[];
    tttt=[];
    ttt2=[];
    dd=2;
    oomega=.000001:.001:.3;
    for ii=1:length(oomega)
        [G,F,Gamma] = valuation(oomega(ii),sig);
        tt2(ii)=1-(Gamma-mu*G)*sp1;
        ttt(ii)=(1-Gamma);
        [G,F,Gamma] = valuation(oomega(ii),sig*dd);
        ttt2(ii)=1-(Gamma-mu*G)*sp1;
        tttt(ii)=(1-Gamma);
    end
    %leverage implied by utility function, for given Ubar and omega
    Ljj=Ubar./(ttt*sp1);
    %only interested in positive borrowing case, i.e., leverage>=1
    JJ=find(Ljj>=1);
    plot(1./tt2,oomega,'+-',Ljj(JJ),oomega(JJ),lev_SS,omegabar,'*')
    hold on
    
    [omega,er] = ffindomeg(sig*dd,mu,sp1);
    [ff,G,F,Gamma,Gam_muG,Fprime]=findomeg(omega,sig*dd,mu,sp1);
    if abs(ff) > .1e-10 | isnan(ff) == 1
        error('fatal (micro) mistake')
    end
    lev=1/(1-Gam_muG*sp1);
    Pe=sp1*omega*lev/(lev-1);
    Ubart=(1-Gamma)*sp1*lev;
    LLjj=Ubart./(tttt*sp1);
    JJJ=find(LLjj>=1);
    plot(1./ttt2,oomega,'+-',LLjj(JJJ),oomega(JJJ),lev,omega,'o')
    
    ylabel('\omega - bar','fontsize',36)
    xlabel('leverage','fontsize',36)
    title('Static equilibrium','fontsize',46)
    axis tight
end

ddd=2.0;
figure('name','sigma shock')
oomega=.001:.01:3;
f=[];
fp=[];
for ii = 1:length(oomega)
    omega=oomega(ii);
    z       =   (log(omega)+sig^2/2)/sig;
    f(ii)       =   normpdf(z)/(omega*sig);
    f(ii) = logncdf(omega,-1/2*sig^2,sig);
    zp       =   (log(omega)+(sig*ddd)^2/2)/(sig*ddd);
    fp(ii)       =   normpdf(zp)/(omega*sig*ddd);
    fp(ii) = logncdf(omega,-1/2*(sig*ddd)^2,sig*ddd);
end
plot(oomega,f,'*-',oomega,fp)
ylabel('density')
xlabel('\omega')
title('Impact on log normal density of doubling standard deviation')
axis tight

if idx==0
    return
end

oomega=.001:.01:6;
f=[];
figure('name','log normal density function')
for ii = 1:length(oomega)
    omega=oomega(ii);
    f(ii) = lognpdf(omega,-1/2*sig^2,sig);
end
plot(oomega,f)
ylabel('density','fontsize',20)
xlabel('\omega','fontsize',20)
ss=['Log normal density function, E\omega = 1, \sigma = ',num2str(sig)];
title(ss,'fontsize',20)
axis tight


figure('name','criterion')
obj=[];
oomega=.001:.01:10;
for ii=1:length(oomega)
    omega=oomega(ii);
    [G,F,Gamma] = valuation(omega,sig);
    obj(ii)=(1-Gamma)*sp1/(1-sp1*(Gamma-mu*G));
end

plot(oomega,obj,omegabar,Ubar,'*')
ylabel('objective')
xlabel('omega_bar')
title('entrepreneurial utility as a function of omega_bar')
axis tight
